===================================================================== Mode: AsyncIO Services — mode-ng 0.4.0 documentation

# ===================================================================== Mode: AsyncIO Services

|build-status| |coverage| |license| |wheel| |pyversion| |pyimp|

.. include:: ../includes/introduction.txt

.. include:: ../includes/installation.txt

.. include:: ../includes/faq.txt

.. include:: ../includes/code-of-conduct.txt

.. |build-status| image:: https://travis-ci.com/lqhuang/mode-ng.png?branch=master :alt: Build status :target: https://travis-ci.com/lqhuang/mode-ng

.. |coverage| image:: https://codecov.io/github/lqhuang/mode-ng/coverage.svg?branch=master :target: https://codecov.io/github/lqhuang/mode-ng?branch=master

.. |license| image:: https://img.shields.io/pypi/l/mode-ng.svg :alt: BSD License :target: https://opensource.org/licenses/BSD-3-Clause

.. |wheel| image:: https://img.shields.io/pypi/wheel/mode-ng.svg :alt: Mode can be installed via wheel :target: http://pypi.org/project/mode-ng/

.. |pyversion| image:: https://img.shields.io/pypi/pyversions/mode-ng.svg :alt: Supported Python versions. :target: http://pypi.org/project/mode-ng/

.. |pyimp| image:: https://img.shields.io/pypi/implementation/mode-ng.svg :alt: Supported Python implementations. :target: http://pypi.org/project/mode-ng/